<?php
/* $Id: catalan-utf-8.inc.php,v 2.130.2.3 2006/03/23 17:42:11 lem9 Exp $ */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = '.';
$number_decimal_separator = ',';
// abreviatures de Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
$timespanfmt = '%s dies, %s hores, %s minuts i %s segons';

$day_of_week = array('Diu', 'Dll', 'Dma', 'Dcr', 'Djs', 'Div', 'Dis');
$month = array('Gen', 'Feb', 'Mar', 'Abr', 'Mai', 'Jun', 'Jul', 'Ago', 'Set', 'Oct', 'Nov', 'Dec');
// Veure http://www.php.net/manual/es/function.strftime.php per a definir
// la variable seguent
$datefmt = '%d-%m-%Y a les %H:%M:%S';

$strAbortedClients = 'Avortat';
$strAbsolutePathToDocSqlDir = 'S\'ha d\'entrar el camí absolut en el servidor web per el directori de docSQL';
$strAccessDenied = 'Accés denegat';
$strAccessDeniedCreateConfig = 'La raó més probable d\'aixó és que no heu creat l\'arxiu de configuració. Podriau voler utilitzar %1$ssetup script%2$s per crear-ne un.';
$strAccessDeniedExplanation = 'phpMyAdmin ha intentat connectar amb el servidor de MySQL, pero el servidor ha rebutjat la connexió. Comprova el host, el num d\' usuari i la contrasenya al fitxer config.inc.php i mira que es correspongui amb la informació facilitada per l\' administrador del servidor de MySQL.';
$strAction = 'Acció';
$strAddAutoIncrement = 'Afegir valor AUTO_INCREMENT';
$strAddConstraints = 'Afegir restriccions';
$strAddDeleteColumn = 'Afegir/esborrar Camps de Columna';
$strAddDeleteRow = 'Afegir/esborrar fila de criteri';
$strAddDropDatabase = 'Afegir DROP DATABASE';
$strAddedColumnComment = 'Afegit comentari per la columna';
$strAddedColumnRelation = 'Afegida relació per la columna';
$strAddFields = 'Afegir %s camp(s)';
$strAddHeaderComment = 'Afegir comentari personalitzat a la capçalera (\\n divideix linies)';
$strAddIfNotExists = 'Afegir IF NOT EXISTS';
$strAddIntoComments = 'Afegir en comentaris';
$strAddNewField = 'Afegir un camp nou';
$strAddPrivilegesOnDb = 'Afegir permissos a la següent base de dades';
$strAddPrivilegesOnTbl = 'Afegir permissos a la següent taula';
$strAddSearchConditions = 'Afegeix condicions de recerca (cos de la clàusula "WHERE"):';
$strAddToIndex = 'Afegir columna(es) a l\'índex %s &nbsp;';
$strAddUser = 'Afegir un usuari nou';
$strAddUserMessage = 'Has afegit un usuari nou.';
$strAdministration = 'Administració';
$strAffectedRows = 'Files afectades:';
$strAfter = 'Després %s';
$strAfterInsertBack = 'Tornar';
$strAfterInsertNewInsert = 'Insereix un nou registre';
$strAfterInsertNext = 'Editar el següent registre'; 
$strAfterInsertSame = 'Tornar a aquesta plana';
$strAllowInterrupt = 'Permetre l\'interrupció de l\'importació en cas de que l\'arxiu d\'ordres detecti que s\'acosta el limit del temps. Pot ser una bona solució per importar arxius grans, però pot trencar transaccions.';
$strAllTableSameWidth = 'Mostrar totes les taules amb la mateixa amplada?';
$strAll = 'Tot';
$strAlterOrderBy = 'Altera la taula i ordena per';
$strAnalyzeTable = 'Analitza la taula';
$strAnd = 'I';
$strAndThen = 'i llavors';
$strAnIndex = 'S\'ha afegit un índex a %s';
$strAnyHost = 'Qualsevol servidor';
$strAny = 'Qualsevol';
$strAnyUser = 'Qualsevol usuari';
$strApproximateCount = 'Pot ser aproximat. Veure FAQ 3.11';
$strAPrimaryKey = 'S\'ha afegit una clau principal a %s';
$strArabic = 'Àrab';
$strArmenian = 'Armeni';
$strAscending = 'Ascendent';
$strAtBeginningOfTable = 'Al principi de la taula';
$strAtEndOfTable = 'Al final de la taula';
$strAttr = 'Atributs';
$strAutodetect = 'Autodetectar';
$strAutomaticLayout = 'Disseny automàtic';

$strBack = 'Enrere';
$strBaltic = 'Bàltic';
$strBeginCut = 'INICI DEL TALL';
$strBeginRaw = 'INICI DEL VOLCAT';
$strBinary = ' Binari ';
$strBinaryDoNotEdit = ' Binari - no editeu ';
$strBinaryLog = 'Registre binari';
$strBinLogEventType = 'Tipus d\'event';
$strBinLogInfo = 'Informació';
$strBinLogName = 'Nom del registre';
$strBinLogOriginalPosition = 'Posició original';
$strBinLogPosition = 'Posició';
$strBinLogServerId = 'ID de Servidor';
$strBookmarkAllUsers = 'Deixar accedir a cada usuari a aquesta consulta desada';
$strBookmarkCreated = '%s creat com a consulta desada';
$strBookmarkDeleted = 'S\'ha esborrat la consulta desada.';
$strBookmarkLabel = 'Etiqueta';
$strBookmarkQuery = 'Consulta SQL desada';
$strBookmarkReplace = 'Reemplaçar una consulta desada ja existent amb el mateix nom';
$strBookmarkThis = 'Desa aquesta consulta SQL';
$strBookmarkView = 'Només mirar';
$strBrowseDistinctValues = 'Navega per valors diferents';
$strBrowseForeignValues = 'Navega valors externs';
$strBrowse = 'Navega';
$strBufferPool = 'Grup de memòries intermitges';
$strBufferPoolUsage = 'Ús del grup de memòries intermitges';
$strBulgarian = 'Búlgar';
$strBusyPages = 'Planes ocupades';
$strBzError = 'phpMyAdmin és incapaç de comprimir el volcat degut a una extensió Bz2 incorrecta en aquesta versió de php. És molt recomenable posar a la directiva <code>$cfg[\'BZipDump\']</code> el valor <code>FALSE</code> al fitxer de configuració de phpMyAdmin. Si vols utilitzar les facilitats de compresió Bz2, és necessari actualitzar el php a la darrera versió disponible. Es pot consultar el informe d\'errada %s de php per a més detalls.';
$strBzip = '"comprimit amb bzip"';

$strCalendar = 'Calendari';
$strCanNotLoadImportPlugins = 'No es poden carregar les extensions d\'importació, comproveu l\'instal.lació!';
$strCannotLogin = 'No podem connectar amb el servidor MySQL';
$strCantLoad = 'No puc carregar la extensió %s,<br />comprova la configuració de PHP.';
$strCantLoadRecodeIconv = 'No es pot carregar iconv o recodificar una extensió necessària per la conversió de jocs de caràcters, configura php per permetre l\'ús d\'aquestes extensions o bé desactiva la conversió de jocs de caràcters en phpMyAdmin.';
$strCantRenameIdxToPrimary = 'No pots canviar el nom d\'un índex a "PRIMARY"!';
$strCantUseRecodeIconv = 'No es pot utilitzar iconv ni libiconv ni la funció recode_string mentre es carrega l\'extensió d\'informes. Comprova la configuració de php.';
$strCardinality = 'Cardinalitat';
$strCaseInsensitive = 'No sensible a majúscules';
$strCaseSensitive = 'sensible a majúscules';
$strCentralEuropean = 'Europa Central';
$strChange = 'Canvi';
$strChangeCopyModeCopy = '... respecta l\'antic.';
$strChangeCopyMode = 'Crea un nou usuari amb els mateixos permissos i ...';
$strChangeCopyModeDeleteAndReload = ' ... esborra l\'antic de les taules d\'usuaris i recarrega els permissos després.';
$strChangeCopyModeJustDelete = ' ... esborra l\'antic de les taules d\'usuaris.';
$strChangeCopyModeRevoke = ' ... treu tots els permissos actius de l\'antic i esborra\'l després.';
$strChangeCopyUser = 'Canvi d\'Informació de Connexió / Copia d\'Usuari';
$strChangeDisplay = 'Tria el camp a mostrar';
$strChangePassword = 'Canvi de contrasenya';
$strCharset = 'Joc de Caracters';
$strCharsetOfFile = 'Joc de caràcters de l\'arxiu:';
$strCharsetsAndCollations = 'Jocs de Caracters i ordenacions';
$strCharsets = 'Jocs de caracters';
$strCheckAll = 'Verificar-ho tot';
$strCheckOverhead = 'Comprovar taules desfragmentades';
$strCheckPrivs = 'Comprova els Permissos';
$strCheckPrivsLong = 'Comprova els Permissos per la Base de dades &quot;%s&quot;.';
$strCheckTable = 'Verifica la taula';
$strChoosePage = 'Tria una pàgina per editar';
$strColComFeat = 'Mostrant comentaris de les columnes';
$strCollation = 'Ordenaciò';
$strColumnNames = 'Nom de les columnes';
$strColumnPrivileges = 'Permissos específics de columna';
$strCommand = 'Ordre';
$strComments = 'Comentaris';
$strCommentsForTable = 'COMENTARIS PER LA TAULA';
$strCompatibleHashing = 'Compatible amb MySQL&nbsp;4.0';
$strCompleteInserts = 'Completar insercions';
$strCompression = 'Compressió';
$strCompressionWillBeDetected = 'La compresió de l\'arxiu importat es detectarà automàticament des de: %s';
$strConfigDefaultFileError = 'No es pot carregar la configuració per defecte des de: "%1$s"';
$strConfigFileError = 'phpMyAdmin és incapaç de llegir el fitxer de configuració!<br />Això pot succeir si php troba un error sintàctic en ell o bé php no pot trobar el fitxer.<br />Intenta obrir el fitxer de configuració directament fent servir l\'enllaç següent i comprova el(s) missatge(s) d\'error que reps. En moltes ocasions una coma o punt i coma falta en algun lloc.<br />Si reps una plana en blanc, tot està bé.';
$strConfigureTableCoord = 'Configura les coordinades per la taula %s';
$strConnectionError = 'No puc connectar: paràmetres incorrectes.';
$strConnections = 'Connexions';
$strConstraintsForDumped = 'Restriccions per taules volcades';
$strConstraintsForTable = 'Restriccions per la taula';
$strCookiesRequired = 'A partir d\'aquest punt és necessari tenir les galetes (cookies) activades.';
$strCopy = 'Copiar'; 
$strCopyDatabaseOK = 'La Base de dades %s s\'ha copiat a %s';
$strCopyTable = 'Copia taula a (base-de-dades<b>.</b>taula):';
$strCopyTableOK = 'La taula %s s\'ha copiat a %s.';
$strCopyTableSameNames = 'No es pot copiar la taula sobre ella mateixa';
$strCouldNotKill = 'phpMyAdmin no pot cancel.lar el fil %s. Probablement, ja és tancat.';
$strCreate = 'Crear';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE abans de copiar';
$strCreateIndex = 'Crea un índex a la columna:&nbsp;%s';
$strCreateIndexTopic = 'Crea un nou índex';
$strCreateNewDatabase = 'Crea una nova base de dades';
$strCreateNewTable = 'Crear una taula nova a la base de dades %s';
$strCreatePage = 'Crea una nova Pàgina';
$strCreatePdfFeat = 'Creació de PDFs';
$strCreationDates = 'Datas de Creació/Modificació/Comprovació';
$strCriteria = 'Criteris';
$strCroatian = 'Croata';
$strCSV = 'CSV';
$strCSVImportOptions = 'Opcions de CSV';
$strCSVOptions = 'Opcions CSV';
$strCyrillic = 'Ciríl.lic';
$strCzechSlovak = 'Txec-Eslovac';
$strCzech = 'Txec';

$strDanish = 'Danès';
$strDatabase = 'Base de dades';
$strDatabaseEmpty = 'El nom de la base de dades és buit!';
$strDatabaseExportOptions = 'Opcions d\'exportació de Bases de Dades';
$strDatabaseHasBeenDropped = 'La Base de Dades %s s\'ha eliminat.';
$strDatabaseNoTable = 'Aquesta base de dades no té taules!';
$strDatabases = 'bases de dades';
$strDatabasesDropped = '%s Bases de dades s\'han esborrat correctament.';
$strDatabasesStatsDisable = 'Desactiva Estadístiques';
$strDatabasesStatsEnable = 'Activa Estadístiques';
$strDatabasesStats = 'Estadístiques de les bases de dades';
$strDatabasesStatsHeavyTraffic = 'Nota: Activant les estadístiques de Base de Dades aqui pot provocar elevat tràfic entre el servidor Web i el de MySQL.';
$strData = 'Dades';
$strDataDict = 'Diccionari de Dades';
$strDataOnly = 'Només dades';
$strDataPages = 'Planes contenint dades';
$strDBComment = 'Comentaris de la Base de Dades: ';
$strDBCopy = 'Copiar base de dades a';
$strDBGContext = 'Contexte';
$strDBGContextID = 'ID de contexte';
$strDBGHits = 'Accessos';
$strDBGLine = 'Linia';
$strDBGMaxTimeMs = 'Temps max, ms';
$strDBGMinTimeMs = 'Temps min, ms';
$strDBGModule = 'Módul';
$strDBGTimePerHitMs = 'Temps/Accés, ms';
$strDBGTotalTimeMs = 'Temps total, ms';
$strDbPrivileges = 'Permissos especifics de Base de dades';
$strDBRename = 'Reanomenar base de dades a';
$strDbSpecific = 'específic de la base de dades';
$strDefault = 'Defecte';
$strDefaultEngine = '%s és el motor d\'emmagatzematge per defecte en aquest servidor MySQL.';
$strDefaultValueHelp = 'Per a valors per defecte, només entra un valor, sense barres invertides ni cometes, fent servir aquest format: a';
$strDefragment = 'Desfragmentar taula';
$strDelayedInserts = 'Usa insercions diferides';
$strDeleteAndFlushDescr = 'Aquesta és la forma més clara, pero recarregar els permissos pot tardar una mica.';
$strDeleteAndFlush = 'Esborra els usuaris i recarrega els permissos seguidament.';
$strDeleted = 'La fila ha estat esborrada';
$strDeletedRows = 'Files esborrades:';
$strDelete = 'Esborrar';
$strDeleteNoUsersSelected = 'No hi ha usuaris sel.leccionats per esborrar!';
$strDeleting = 'Esborrant %s';
$strDelOld = 'La plana actual té referències a taules que no existeixen. Vols esborrar aquestes referències?';
$strDescending = 'Descendent';
$strDescription = 'Descripció';
$strDictionary = 'diccionari';
$strDirtyPages = 'Planes brutes';
$strDisabled = 'Desactivat';
$strDisableForeignChecks = 'Desactivar comprovacions de claus externes';
$strDisplayFeat = 'Mostrar característiques';
$strDisplayOrder = 'Ordre del llistat:';
$strDisplayPDF = 'Mostrar esquema PDF';
$strDoAQuery = 'Fer una "petició segons exemple" (comodí: "%")';
$strDocu = 'Documentació';
$strDoYouReally = 'Realment vols fer?';
$strDropDatabaseStrongWarning = 'Ets a punt d\' ELIMINAR completament una base de dades!';
$strDrop = 'Eliminar';
$strDropUsersDb = 'Esborra les bases de dades que tenen els mateixos noms que els usuaris.';
$strDumpingData = 'Volcant dades de la taula';
$strDumpSaved = 'El volcat s\'ha guardat amb el nom d\'arxiu %s.';
$strDumpXRows = 'Volcar %s files començant a la fila %s.';
$strDynamic = 'dinàmic';

$strEdit = 'Editar';
$strEditPDFPages = 'Editar pàgines PDF';
$strEditPrivileges = 'Editar permissos';
$strEffective = 'Efectiu';
$strEmpty = 'Buidar';
$strEmptyResultSet = 'MySQL ha retornat un conjunt buit (p.e. cap fila).';
$strEnabled = 'Activat';
$strEncloseInTransaction = 'Incloure exportació en la transacció';
$strEndCut = 'FI DEL TALL';
$strEnd = 'Final';
$strEndRaw = 'FI DEL VOLCAT';
$strEngineAvailable = '%s està disponible en aquest servidor MySQL.';
$strEngineDisabled = '%s s\'ha desactivat en aquest servidor MySQL.';
$strEngines = 'Motors';
$strEngineUnsupported = 'Aquest servidor MySQL no soporta el motor d\'emmagatzematge %s.';
$strEnglish = 'Anglès';
$strEnglishPrivileges = ' Nota: Els noms dels privilegis del MySQL són en llengua anglesa ';
$strError = 'Errada';
$strErrorInZipFile = 'Error en arxiu ZIP:';
$strEscapeWildcards = 'Els comodins _ i % han de marcar-se amb una \ per usar-los literalment';
$strEsperanto = 'Esperanto';
$strEstonian = 'Estonià ';
$strExcelEdition = 'Edició per Excel';
$strExcelOptions = 'Opcions d\'Excel';
$strExecuteBookmarked = 'Executa una consulta desada';
$strExplain = 'Explicació de l\'SQL';
$strExport = 'Exportar';
$strExtendedInserts = 'Insercions ampliades';
$strExtra = 'Extra';

$strFailedAttempts = 'Intents erronis';
$strField = 'Camp';
$strFieldHasBeenDropped = 'S\'ha esborrat el camp %s';
$strFields = 'Camps';
$strFieldsEmpty = ' El comptador de camps és buit! ';
$strFieldsEnclosedBy = 'Camps englobats per';
$strFieldsEscapedBy = 'Camps amb marca d\'escapada';
$strFieldsTerminatedBy = 'Camps acabats per';
$strFileAlreadyExists = 'L\'arxiu %s ja existeix al servidor, canvia el nom o marca l\'opció de sobreescriure.';
$strFileCouldNotBeRead = 'No es pot llegir el fitxer';
$strFileNameTemplateDescription = 'Aquest valor es interpretat usant %1$sstrftime%2$s, pel que podeu usar les cadenes de formateig de temps. Ademès, es faràn aquestes transformacions: %3$s. Altre text es deixarà sense variació.';
$strFileNameTemplateDescriptionDatabase = 'nom de base de dades';
$strFileNameTemplateDescriptionServer = 'nom de servidor';
$strFileNameTemplateDescriptionTable = 'nom de taula';
$strFileNameTemplate = 'Nom de fitxer de plantilla';
$strFileNameTemplateRemember = 'Recordar plantilla';
$strFileToImport = 'Arxiu a importar';
$strFixed = 'fixa';
$strFlushPrivilegesNote = 'Nota: phpMyAdmin obté els permissos de l\'usuari directament de les taules de permissos de l\' MySQL. El contingut d\'aquestes taules pot diferir dels permissos que utilitza el servidor si s\'han fet canvis manualment. En aquest cas, es necessari %srecarregar els permissos%s abans de continuar.';
$strFlushQueryCache = 'Buidar la memòria intermèdia de consultes';
$strFlushTable = 'Buidar la memòria cau de la taula ("FLUSH")';
$strFlushTables = 'Sincronitzar (tancar) totes les taules';
$strFormat = 'Format';
$strFormEmpty = 'Falta un valor al formulari !';
$strFreePages = 'Planes lliures';
$strFullText = 'Textos sencers';
$strFunction = 'Funció';

$strGenBy = 'Generat per';
$strGeneralRelationFeat = 'Característiques generals de relacions';
$strGenerate = 'Generar'; 
$strGeneratePassword = 'Generar Contrasenya'; 
$strGenTime = 'Temps de generació';
$strGeorgian = 'Georgià';
$strGerman = 'Alemany';
$strGlobal = 'global';
$strGlobalPrivileges = 'Permissos generals';
$strGlobalValue = 'Valor global';
$strGo = 'Executar';
$strGrantOption = 'Atorgar';
$strGreek = 'Grec';
$strGzip = '"comprimit amb gzip"';

$strHandler = 'Gestor';
$strHasBeenAltered = 'ha estat alterada.';
$strHasBeenCreated = 'ha estat creada.';
$strHaveToShow = 'Has d\'escollir al menys una columna per mostrar';
$strHebrew = 'Hebreu';
$strHexForBinary = 'Usa hexadecimal per camps binaris';
$strHome = 'Inici';
$strHomepageOfficial = 'Plana oficial del phpMyAdmin';
$strHostEmpty = 'El nom del servidor és buit!';
$strHost = 'Servidor';
$strHungarian = 'Húngar';

$strIcelandic = 'Islandés';
$strId = 'ID';
$strIdxFulltext = 'Text sencer';
$strIgnoreDuplicates = 'Ignorar files duplicades';
$strIgnore = 'Ignora';
$strIgnoreInserts = 'Utilitzar "ignore inserts"';
$strIgnoringFile = 'Ignorant fitxer %s';
$strImportDocSQL = 'Importa Arxius docSQL';
$strImportFiles = 'Importar fitxers';
$strImportFormat = 'Format de l\'arxiu importat';
$strImport = 'Importar';
$strImportSuccessfullyFinished = 'Importació finalitzada correctament, %d consultes executades.';
$strIndexes = 'Indexos';
$strIndexHasBeenDropped = 'S\'ha esborrat l\'índex %s';
$strIndex = 'Índex';
$strIndexName = 'Nom d\'índex:';
$strIndexType = 'Tipus d\'índex:';
$strIndexWarningMultiple = 'Més d\'una clau %s s\'ha creat per a la columna `%s`';
$strIndexWarningPrimary = 'Les claus PRIMARY i INDEX no es poden establir alhora per a la columna `%s`';
$strIndexWarningTable = 'Problemes amb els index de la taula `%s`';
$strIndexWarningUnique = 'Les claus UNIQUE i INDEX no es poden establir alhora per a la columna `%s`';
$strInnoDBAutoextendIncrementDesc = ' La quantitat a incrementar per ampliar el tamany d\'una taula autoextensible quan estigui a punt d\'omplir-se.';
$strInnoDBAutoextendIncrement = 'Increment d\'autoextensió';
$strInnoDBDataFilePath = 'Arxius de dades';
$strInnoDBDataHomeDirDesc = 'La part comuna de la ruta al directori per tots els arxius de dades InnoDB.';
$strInnoDBDataHomeDir = 'Directori local de dades';
$strInnodbStat = 'Estat InnoDB';
$strInsecureMySQL = 'El vostre fitxer de configuració té paràmetres (root sense contrasenya) que corresponen al compte privilegiat predetermitat de MySQL. El servidor MySQL està funcionant amb aquests valors, el que significa un forat de seguretat, i s\'exposa a intrusions, pel que recomanem la reparació urgent d\'aquest forat de seguretat.';
$strInsertAsNewRow = 'Inserir com a nova fila';
$strInsertedRowId = 'Id de la fila inserida:';
$strInsertedRows = 'Files Inserides:';
$strInsert = 'Insereix';
$strInsertNewRow = 'Inserir nova fila';
$strInternalNotNecessary = '* No es necessita una relació interna si ja existeix a InnoDB.';
$strInternalRelations = 'Relacions internes';
$strInUse = 'en ús';
$strInvalidAuthMethod = 'Mètode d\'identificació incorrecte establert a la configuració:';
$strInvalidColumnCount = 'El comptador de columnes ha de ser més gran que zero.';
$strInvalidColumn = 'S\'ha especificat una columna incorrecta (%s)!';
$strInvalidCSVFieldCount = 'Comptador de camps incorrecte en l\'entrada CSV a la línia %d.';
$strInvalidCSVFormat = 'Format incorrecte a l\'entrada CSV a la línia %d.';
$strInvalidCSVParameter = 'Paràmetre incorrecte per importació CSV: %s';
$strInvalidFieldAddCount = 'Heu d\'afegir al menys un camp.';
$strInvalidFieldCount = 'La taula ha de tenir al menys un camp.';
$strInvalidLDIImport = 'Aquesta extensió no suporta importacions comprimides!';
$strInvalidRowNumber = '%d no és un num. vàlid de fila.';
$strInvalidServerHostname = 'Nom de host invàlid pel servidor %1$s. Si us plau, reviseu la configuració.';
$strInvalidServerIndex = 'Index de servidor invàlid: "%s"';

$strJapanese = 'Japonès';
$strJoins = 'Unions';
$strJumpToDB = 'Vés a la Base de Dades &quot;%s&quot;.';
$strJustDeleteDescr = 'Els usuaris &quot;esborrats&quot; encara tindrán accés al servidor com fins ara mentre no es recarreguin els permissos.';
$strJustDelete = 'Només esborra els usuaris de les taules de permissos.';

$strKeepPass = 'No canviïs la contrasenya';
$strKeyCache = 'Memòria intermèdia de claus';
$strKeyname = 'Nom Clau';
$strKill = 'Finalitzar';
$strKorean = 'Coreà';

$strLandscape = 'Horitzontal';
$strLanguageFileNotFound = 'Arxiu d\'idioma "%1$s" no trobat.';
$strLanguageUnknown = 'Idioma desconegut: %1$s.';
$strLatchedPages = 'Planes inalterables';
$strLatexCaption = 'Titol de Taula';
$strLatexContent = 'Contingut de la taula __TABLE__';
$strLatexContinuedCaption = 'Continuació del Titol de taula';
$strLatexContinued = '(continúa)';
$strLatexIncludeCaption = 'Inclusió del titol de taula';
$strLatexLabel = 'Etiqueta de clau';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'Opcions LaTeX';
$strLatexStructure = 'Estructura de la taula __TABLE__';
$strLatvian = 'Letó';
$strLDI = 'CSV usant LOAD DATA';
$strLDIImportOptions = 'Opcions per importació CSV usant LOAD DATA';
$strLDILocal = 'Usa clau LOCAL';
$strLengthSet = 'Longitud/Valors*';
$strLimitNumRows = 'registres per plana';
$strLinesTerminatedBy = 'Línies acabades amb';
$strLinkNotFound = 'No s\'ha trobat l\'enllaç ';
$strLinksTo = 'Enllaços a';
$strLithuanian = 'Lituà ';
$strLocalhost = 'Local';
$strLocationTextfile = 'Ubicació del fitxer de text';
$strLogin = 'Identificació';
$strLoginInformation = 'Informació d\'Identificació';
$strLogout = 'Sortir';
$strLogPassword = 'Contrasenya:';
$strLogServer = 'Servidor';
$strLogUsername = 'Nom d\'Usuari:';
$strLongOperation = 'Aquesta operació pot ser bastant llarga. Procedim igualment?';

$strMaxConnects = 'max. connexions simultànies';
$strMaximalQueryLength = 'Tamany màxim de la consulta creada';
$strMaximumSize = 'Tamany Màxim: %s%s';
$strMbExtensionMissing = 'No s\'ha trobat la extensió de PHP mbstring i sembla que feu servir un joc de caracters multibyte. Sense la extensió mbstring, phpMyAdmin és incapaç de dividir cadenes de text correctament i pot generar resultats inesperats.';
$strMbOverloadWarning = 'Teniu activada la funció mbstring.func_overload a la configuració del vostre PHP. Aquesta opció és incompatible amb phpMyAdmin i pot provocar la perdua de dades!';
$strMIME_available_mime = 'Tipus MIME disponibles';
$strMIME_available_transform = 'Transformacions disponibles';
$strMIME_description = 'Descripció';
$strMIME_MIMEtype = 'Tipus MIME';
$strMIME_nodescription = 'No hi ha cap descripció disponible per a aquesta transformació.<br />Demana a l\'autor qué fa %s.';
$strMIME_transformation_note = 'Per veure una llista d\'opcions de transformació disponibles i els seus tipus MIME de  transformació, clica a %stransformation descriptions%s';
$strMIME_transformation_options_note = 'Entra els valors per a transformar utilitzant aquest format: \'a\',\'b\',\'c\'...<br />Si mai necessites escriure una barra invertida ("\") o un apòstrof ("\'") entre aquests valors, posa una barra invertida devant (per exemple \'\\\\xyz\' o \'a\\\'b\').';
$strMIME_transformation_options = 'Opcions de Transformació';
$strMIME_transformation = 'Transformació del Navegador';
$strMIMETypesForTable = 'TIPUS MIME PER LA TAULA';
$strMIME_without = 'Els tipus MIME en cursiva no tenen funcions de transformació a part';
$strModifications = 'Les modificacions han estat guardades';
$strModifyIndexTopic = 'Modifica un índex';
$strModify = 'Modificar';
$strMoveTable = 'Mou taula a (base-de-dades<b>.</b>taula):';
$strMoveTableOK = 'Taula %s moguda a %s.';
$strMoveTableSameNames = 'No es pot moure la taula sobre ella mateixa!';
$strMultilingual = 'multilingüe';
$strMyISAMDataPointerSizeDesc = 'El tamany per defecte de l\'apuntador en bytes, usat en CREATE TABLE per a taules MyISAM quan no s\'especifica l\'opció MAX_ROWS.';
$strMyISAMDataPointerSize = 'Tamany de l\'apuntador de dades';
$strMyISAMMaxExtraSortFileSizeDesc = 'Si l\'arxiu temporal usat per creació ràpida d\'un índex MyISAM pot ser més gran que usant el cau principal per la quantitat especificada aquí, es recomana fer servir el cau principal.';
$strMyISAMMaxExtraSortFileSize = 'Màxim tamany per arxius temporals en creació d\'índex';
$strMyISAMMaxSortFileSizeDesc = 'El tamany màxim per arxius temporals de MySQL es permet usar-lo mentre es torna acrear un índex MyISAM (mentre es fa un REPAIR TABLE, ALTER TABLE, o LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Tamany màxim per arxius temporals de classificació';
$strMyISAMRecoverOptionsDesc = 'El modus per a recuperació automàtica en taules MyISAM corruptes, com s\'estableix via l\'opció d\'inici del servidor --myisam-recover.';
$strMyISAMRecoverOptions = 'Modus de recuperació automàtic';
$strMyISAMRepairThreadsDesc = 'Si aquest valor és més gran que 1, els índexos de taules  MyISAM es creen en paralel (cada índex en el seu propi fil) mentre s\'executa el procés de reparació per classificació.';
$strMyISAMRepairThreads = 'Reparar fils';
$strMyISAMSortBufferSizeDesc = 'Ârea assignada per classificar índexos MyISAM mentre es fa un REPAIR TABLE o mentre es creen índexos amb CREATE INDEX o ALTER TABLE.';
$strMyISAMSortBufferSize = 'Tamany de l\'àrea de classificació';
$strMySQLCharset = 'Joc de caràcters de MySQL';
$strMysqlClientVersion = 'Versió del client MySQL';
$strMySQLConnectionCollation = 'Ordenació de la connexió MySQL'; 
$strMySQLSaid = 'MySQL diu: ';
$strMySQLShowProcess = 'Mostrar processos';
$strMySQLShowStatus = 'Mostra la informació de funcionament del MySQL';
$strMySQLShowVars = 'Mostra les variables de sistema del MySQL';

$strName = 'Nom';
$strNext = 'Següent';
$strNoActivity = 'Sense activitat des de fa %s segons o més, entra de nou';
$strNoDatabases = 'No hi ha Bases de Dades';
$strNoDatabasesSelected = 'No hi han Bases de dades sel.leccionades.';
$strNoDescription = 'Sense Descripció';
$strNoDetailsForEngine = 'No hi ha informació detallada de l\'estat disponible per a aquest motor d\'emmagatzematge.';
$strNoDropDatabases = 'Instrucció "DROP DATABASE" desactivada.';
$strNoExplain = 'Saltar l\'explicació de l\'SQL';
$strNoFilesFoundInZip = 'No s\'han trobat arxius dins de l\'arxiu ZIP!';
$strNoFrames = 'phpMyAdmin és més fàcil amb un navegador que <b>suporti marcs (frames)</b>.';
$strNoIndex = 'No s\'ha definit l\'índex!';
$strNoIndexPartsDefined = 'No s\'han definit parts de l\'índex!';
$strNoModification = 'Sense canvis';
$strNone = 'Res';
$strNo = 'No';
$strNoOptions = 'Aquest format no té opcions';
$strNoPassword = 'Sense contrasenya';
$strNoPermission = 'El servidor web no té permissos per a guardar l\'arxiu %s.';
$strNoPhp = 'Sense codi PHP';
$strNoPrivileges = 'Sense permissos';
$strNoRights = 'No tens prou permissos per visualitzar aquesta informació!';
$strNoRowsSelected = 'No s\'han seleccionat files';
$strNoSpace = 'No hi ha prou espai per guardar  l\'arxiu %s.';
$strNoTablesFound = 'Base de dades sense taules.';
$strNoThemeSupport = 'No hi ha suport pels temes, si et plau comprova la teva configuració i/o els teus temes al directori %s.';
$strNothingToImport = 'No heu entrat dades per importar!';
$strNotNumber = 'Aquest valor no és un número!';
$strNotOK = 'Incorrecte';
$strNotSet = 'Taula <b>%s</b> no trobada o no definida a %s';
$strNoUsersFound = 'No s\'han trobat usuaris.';
$strNoValidateSQL = 'Saltar la Validació de l\'SQL';
$strNull = 'Nul';
$strNumberOfFields = 'Nombre de camps';
$strNumSearchResultsInTable = '%s resultat(s) a la taula <i>%s</i>';
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> resultat(s)';
$strNumTables = 'Taules';

$strOK = 'Correcte';
$strOpenNewWindow = 'Obrir nova finestra de phpMyAdmin';
$strOperations = 'Operacions';
$strOperator = 'Operador';
$strOptimizeTable = 'Optimitza la taula';
$strOr = 'O';
$strOverhead = 'Defragmentat';
$strOverwriteExisting = 'Sobreescriure arxiu(s) existent(s)';

$strPageNumber = 'Número de pàgina:';
$strPagesToBeFlushed = 'Planes per a purgar';
$strPaperSize = 'Tamany de paper';
$strPartialImport = 'Importació parcial';
$strPartialText = 'Textos Parcials';
$strPasswordChanged = 'La contrasenya per a %s s\'ha canviat correctament.';
$strPassword = 'Contrasenya';
$strPasswordEmpty = 'La contrasenya és buida!';
$strPasswordHashing = 'Contrasenya Hashing';
$strPasswordNotSame = 'Les contrasenyes no coincideixen!';
$strPdfDbSchema = 'Esquema de la base de dades "%s" - Pàgina %s';
$strPdfInvalidTblName = 'La taula "%s" no existeix!';
$strPdfNoTables = 'No hi ha taules';
$strPDFOptions = 'Opcions PDF';
$strPDF = 'PDF';
$strPDFReportTitle = 'Títol de llistat';
$strPerHour = 'per hora';
$strPerMinute = 'per minut';
$strPerSecond = 'per segon';
$strPersian = 'Persa';
$strPhoneBook = 'Libreta d\' adreces';
$strPHP40203 = 'S\'esta fent servir la versió 4.2.3 de PHP, que té un serios error amb cadenes de multi-byte (mbstring). Mira l\'informe d\'error 19404 de PHP. No es recomana aquesta versió de PHP per treballar amb phpMyAdmin.';
$strPhp = 'Crear codi PHP';
$strPHPVersion = 'PHP versió';
$strPmaDocumentation = 'Documentació de phpMyAdmin';
$strPmaUriError = 'La directiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> HA d\'estar al fitxer de configuració!';
$strPolish = 'Polac';
$strPortrait = 'Vertical';
$strPos1 = 'Inici';
$strPrevious = 'Anterior';
$strPrimaryKeyHasBeenDropped = 'S\'ha esborrat la clau principal';
$strPrimaryKeyName = 'El nom de la clau principal ha de ser ... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>ha de ser</b> el nom i <b>només</b> el nom de la clau principal!)';
$strPrimary = 'Principal';
$strPrint = 'Imprimir';
$strPrintViewFull = 'Vista d\'impresió (amb texts sencers)';
$strPrintView = 'Imprimir vista';
$strPrivDescAllPrivileges = 'Inclou tots els permissos excepte GRANT (atorgar).';
$strPrivDescAlter = 'Permet alterar l\'estructura de taules existents.';
$strPrivDescAlterRoutine = 'Permet alterar i esborrar rutines enmagatzemades.'; 
$strPrivDescCreateDb = 'Permet crear noves bases de dades i taules.';
$strPrivDescCreateRoutine = 'Permet crear rutines enmgatzemades.';  
$strPrivDescCreateTbl = 'Permet crear noves taules.';
$strPrivDescCreateTmpTable = 'Permet crear taules temporals.';
$strPrivDescCreateUser = 'Permet crear, esborrar i reanomenar comptes d\'usuari.'; 
$strPrivDescCreateView = 'Permet crear noves vistes.';  
$strPrivDescDelete = 'Permet esborrar dades.';
$strPrivDescDropDb = 'Permet eliminar bases de dades i taules.';
$strPrivDescDropTbl = 'Permet eliminar taules.';
$strPrivDescExecute5 = 'Permet executar rutines enmagatzemades.'; 
$strPrivDescExecute = 'Permet executar processos enmagatzemats (stored procedures); No té efecte en aquesta versió de MySQL.';
$strPrivDescFile = 'Permet importar i exportar dades amb fitxers externs.';
$strPrivDescGrant = 'Permet afegir usuaris i permissos sense tenir que recarregar les taules de permissos.';
$strPrivDescIndex = 'Permet crear i eliminar indexos.';
$strPrivDescInsert = 'Permet inserir i modificar dades.';
$strPrivDescLockTables = 'Permet bloquejar taules per l\'actual fil d\'execució.';
$strPrivDescMaxConnections = 'Limita el numero de noves connexions que pot obrir l\'usuari per hora.';
$strPrivDescMaxQuestions = 'Limita el numero de consultes que pot enviar l\'usuari al servidor per hora.';
$strPrivDescMaxUpdates = 'Limita el numero d\'ordres que pot executar l\'usuari canviant qualsevol taula o base de dades per hora.';
$strPrivDescMaxUserConnections = 'Límita el nombre de connexions simultànies que l\'usuari pot tenir.';
$strPrivDescProcess3 = 'Permet cancel.lar processos d\'altres usuaris.';
$strPrivDescProcess4 = 'Permet veure completament les consultes a la llista de processos.';
$strPrivDescReferences = 'No té efecte en aquesta versió de MySQL.';
$strPrivDescReload = 'Permet recarregar les configuracions del servidor i buidar les seves memòries cau.';
$strPrivDescReplClient = 'Dona el dret a l\'usuari de preguntar quins servidors mestres / esclaus hi ha.';
$strPrivDescReplSlave = 'Es necessari per a la replicació en servidors esclaus.';
$strPrivDescSelect = 'Permet llegir dades.';
$strPrivDescShowDb = 'Dona accés a la llista completa de bases de dades.';
$strPrivDescShowView = 'Permet fer consultes de tipus SHOW CREATE VIEW.'; 
$strPrivDescShutdown = 'Permet parar el servidor.';
$strPrivDescSuper = 'Permet connectar, encara que s\'hagi arribat al máxim numero de connexions permés; Es necessari per moltes operacions d\'administració com ara establir variables globals o bé cancel.lar fils d\'execució d\'altres usuaris.';
$strPrivDescUpdate = 'Permet canviar dades.';
$strPrivDescUsage = 'Sense permissos.';
$strPrivileges = 'Permissos';
$strPrivilegesReloaded = 'Els permissos s\'han recarregat correctament.';
$strProcesslist = 'Llista de processos';
$strProtocolVersion = 'Versió del protocol';
$strPutColNames = 'Posa els noms de camp a la primera fila';

$strQBE = 'Consulta segons exemple';
$strQBEDel = 'Sup';
$strQBEIns = 'Ins';
$strQueryCache = 'Memòria intermèdia de consultes';
$strQueryFrame = 'Finestra de la Consulta';
$strQueryOnDb = 'Consulta SQL a la base de dades <b>%s</b>:';
$strQuerySQLHistory = 'Historial SQL';
$strQueryStatistics = '<b>Estadístiques de Consultes</b>: Des de l\'últim inici, s\'han enviat %s consultes al servidor.';
$strQueryTime = 'La consulta tarda %s seg';
$strQueryType = 'Tipus de consulta';
$strQueryWindowLock = 'No sobreescriure aquesta consulta des de fora de la finestra';

$strReceived = 'Rebut';
$strRecords = 'Registres';
$strReferentialIntegrity = 'Comprova la integritat referencial:';
$strRefresh = 'Actualitzar';
$strRelationalSchema = 'Esquema Relacional';
$strRelationNotWorking = 'Les característiques addicionals per treballar amb taules enllaçades s\'han desactivat. Per saber perquè clica %saquí%s.';
$strRelationsForTable = 'RELACIONS DE LA TAULA';
$strRelations = 'Relacions';
$strRelationView = 'Vista de Relacions';
$strReloadingThePrivileges = 'Recarregant permissos';
$strReloadMySQL = 'Rellegir el MySQL';
$strRemoveSelectedUsers = 'Treure els usuaris sel.leccionats';
$strRenameDatabaseOK = 'Base de dades %s reanomenada a %s';
$strRenameTableOK = 'La taula %s ha canviat de nom. Ara es diu %s';
$strRenameTable = 'Renombrar les taules a';
$strRepairTable = 'Reparar taula';
$strReplaceNULLBy = 'Substitueix NULL per';
$strReplaceTable = 'Substituir les dades de la taula pel fitxer ';
$strReplication = 'Replicació';
$strReset = 'Esborrar';
$strResourceLimits = 'Limit de recursos';
$strReType = 'Reescriure';
$strRevokeAndDelete = 'Denega tots els permissos actius dels usuaris i els esborra després.';
$strRevokeAndDeleteDescr = 'Els usuaris encara tindran el permís USAGE fins que es recarreguin els permissos.';
$strRevokeMessage = 'Has tret els permissos per %s';
$strRevoke = 'Treure';
$strRomanian = 'Romanés';
$strRowLength = 'Longitud de fila';
$strRows = 'Fila';
$strRowsFrom = 'Files començant des de';
$strRowSize = 'Mida de fila ';
$strRowsModeFlippedHorizontal = 'horizontal (capçaleres rotades)';
$strRowsModeHorizontal = 'horitzontal';
$strRowsModeOptions = ' en mode %s i repeteix capçaleres després de %s cel·les ';
$strRowsModeVertical = 'vertical';
$strRowsStatistic = 'Estadística de files';
$strRunning = 'funcionant a %s';
$strRunQuery = 'Executa consulta';
$strRunSQLQuery = 'Executa consulta/s SQL a la Base de Dades %s';
$strRunSQLQueryOnServer = 'Executar consulta/es SQL al servidor %s';
$strRussian = 'Rus';

$strSave = 'Guardar';
$strSaveOnServer = 'Guardar al servidor al directori %s';
$strScaleFactorSmall = 'El factor de l\'escala és massa petit per posar l\'esquema en una pàgina';
$strSearch = 'Cercar';
$strSearchFormTitle = 'Cercar a la base de dades';
$strSearchInTables = 'A la(les) taula(es):';
$strSearchNeedle = 'Paraula(es) o valor(s) a cercar (comodí: "%"):';
$strSearchOption1 = 'al menys una d\'aquestes paraules';
$strSearchOption2 = 'Totes les paraules';
$strSearchOption3 = 'La frase exacta';
$strSearchOption4 = 'com a expressió regular';
$strSearchResultsFor = 'Resultats de la recerca per a "<i>%s</i>" %s:';
$strSearchType = 'Trobat:';
$strSecretRequired = 'El fitxer de configuració necessita ara una frase de pas secreta (blowfish_secret).';
$strSelectADb = 'Selecciona una Base de Dades';
$strSelectAll = 'Selecciona Tot';
$strSelectBinaryLog = 'Selecciona el registre binari per veure';
$strSelectFields = 'Selecciona els camps (un com a mínim):';
$strSelectNumRows = 'en consulta';
$strSelectTables = 'Selecciona Taules';
$strSend = 'enviar';
$strSent = 'Enviat';
$strServerChoice = 'Elecció de Servidor';
$strServerNotResponding = 'El servidor no respon';
$strServer = 'Servidor';
$strServerStatusDelayedInserts = 'Insercions demorades';
$strServerStatus = 'Informació d\'execució';
$strServerStatusUptime = 'Aquest servidor MySQL és en marxa durant %s. Es va iniciar en %s.';
$strServerTabProcesslist = 'Processos';
$strServerTabVariables = 'Variables';
$strServerTrafficNotes = '<b>Ocupació de servidor</b>: Aquestes taules mostren la ocupació de la xarxa d\'aquest servidor MySQL des de l\'últim inici.';
$strServerVars = 'Variables i configuracions del servidor';
$strServerVersion = 'Versió del servidor';
$strSessionValue = 'Valor de sessió';
$strSetEnumVal = 'Si el tipus de camp és "enum" o "set", entra els valors fent servir el format: \'a\',\'b\',\'c\'...<br />Si mai necessites escriure la barra invertida ("\") o la cometa simple ("\'") abans d\'aquests valors, escriu barres invertides (per exemple \'\\\\xyz\' o \'a\\\'b\').';
$strShowAll = 'Mostra tot';
$strShowColor = 'Mostra color';
$strShowDatadictAs = 'Format del Diccionari de Dades';
$strShowFullQueries = 'Mostra Consultes completes';
$strShowGrid = 'Mostra graella';
$strShowingBookmark = 'Mostrant consultes desades';
$strShowingRecords = 'Mostrant registres: ';
$strShow = 'Mostra';
$strShowOpenTables = 'Mostrar taules obertes';
$strShowPHPInfo = 'Mostra informació de PHP';
$strShowSlaveHosts = 'Mostrar servidors esclaus';
$strShowSlaveStatus = 'Mostrar estat d\'esclaus';
$strShowStatusBinlog_cache_disk_useDescr = 'El nombre de transaccions que han fet servir el registre binari temporal però que excedeixen el valor de  binlog_cache_size i usen un arxiu temporal per desar elements de la transacció.';
$strShowStatusBinlog_cache_useDescr = 'El nombre de transaccions que han fet servir el registre binari temporal.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'El nombre de taules temporals en disc creades automàticament per el servidor mentre executa instruccions. Si Created_tmp_disk_tables és gran, potser vols incrementar el valor de tmp_table_size per fer que les taules temporals treballin en memòria en lloc de treballar en disc.';
$strShowStatusCreated_tmp_filesDescr = 'Cuànts arxius temporals ha creat mysqld.';
$strShowStatusCreated_tmp_tablesDescr = 'El nombre de taules temporals creades en memòria per el servidor mentre executa instruccions.';
$strShowStatusDelayed_errorsDescr = 'El nombre de files escrites amb INSERT DELAYED en les que s\'ha detectar algun error (possile clau duplicada).';
$strShowStatusDelayed_insert_threadsDescr = 'El nombre de gestors de fils de INSERT DELAYED en ús. Cada taula diferent ón s\'usa INSERT DELAYED té el seu propi fil.';
$strShowStatusDelayed_writesDescr = 'El nombre de files escrites amb INSERT DELAYED.';
$strShowStatusFlush_commandsDescr = 'El nombre d\'instruccions FLUSH executades.';
$strShowStatusHandler_commitDescr = 'El nombre d\'instruccions COMMIT internes.';
$strShowStatusHandler_deleteDescr = 'El nombre de vegades que s\'ha esborrat una fila d\'una taula.';
$strShowStatusHandler_discoverDescr = 'El servidor MySQL pot preguntar al motor d\'enmagatzemament NDB Cluster si coneix quelcom taula amb el nom especificat. Aixó s\'anomena descobriment. Handler_discover indica el nombre de taules descobertes.';
$strShowStatusHandler_read_firstDescr = 'El nombre de vegades que s\'ha llegit la primera entrada des d\'un índex. Si és alt, suggereix que el servidor està fent moltes cerques de full index; per exemple, SELECT col1 FROM foo, assumint que col1 és indexat.';
$strShowStatusHandler_read_keyDescr = 'El nombre de peticions basades en una clau per llegir una fila. Si és alt, és una bona indicació de que les consultes i taules estàn indexades adequadament.';
$strShowStatusHandler_read_nextDescr = 'El nombre de peticions per llegir la següent fila en l\'ordre de la clau. Aixó s\'incrementa si s\'està consultant una columna d\'index amb limitació de rang o si s\'està fent una cerca d\'index.';
$strShowStatusHandler_read_prevDescr = 'El nombre de peticions per llegir la fila anterior en l\'ordre de la clau. Aquest mètode de lectura s\'utilitza principalment per optimizar ORDER BY ... DESC.';
$strShowStatusHandler_read_rndDescr = 'El nombre de peticions per llegir una fila basada en una posició fixa. Aixó és alt si es fan moltes consultes que requereixen ordenació del resultat. Probablement tens moltes consultes que fan que MySQL cerqui les taules senceres o bé hi ha joins que no fan servir les claus adequadament.';
$strShowStatusHandler_read_rnd_nextDescr = 'El nombre de peticions per llegir la següent fila a l\'arxiu de dades. Aixó és alt si es fan moltes cerques de taula. Generalment, suggereix que les taules no estàn indexades adequadament o bé les consultes no estàn fetes per aprofitar les avantatges dels índexos definits.';
$strShowStatusHandler_rollbackDescr = 'El nombre d\'instruccions ROLLBACK.';
$strShowStatusHandler_updateDescr = 'El nombre de peticions per a actualitzar una fila en una taula.';
$strShowStatusHandler_writeDescr = 'El nombre de peticions per a insertar una fila en una taula.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'El nombre de planes contenint dades (brutes o netes).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'El nombre de planes actualment brutes.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'El nombre de planes a la memòria intermitja que s\'han demanat per ser actualitzades.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'El nombre de planes lliures.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'El nombre de planes bloquejades a la memòria intermitja de InnoDB. Aquestes planes s\'estàn llegint o escrivint actualment o no es poden actualitzar o esborrar per qualsevol altra raó.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'El nombre de planes en ús degut a que s\'han marcat per tasques administratives com a bloqueixos de files o l\'index del hash adaptatiu. Aquest valor es pot calcular com Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Tamany total de la memòria intermitja, en planes.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'El nombre de lectures aleatòries d\'InnoDB iniciades. Aixó passa quan una consulta cerca en una gran part de una taula però en ordre aleatori.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'El nombre de lectures secuencials d\'InnoDB iniciades. Aixó passa quan InnoDB fa una cerca secuencial a la taula sencera.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'El nombre de peticions de lectures lògiques que InnoDB ha fet.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'El nombre de peticions de lectures lògiques que InnoDB no pot satisfer de la memòria intermitja i ha de fer lectures de planes individuals.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normalment, les escritures a la memòria intermitja d\'InnoDB es fan en segon pla. En canvi, si és necessari llegir o crear una plana i no hi ha planes netes disponibles, fa falta esperar a que primer s\'actualitzin planes. Aquest comptador mostra instàncies d\'aquestes esperes. Si el tamany de la memòria intermitja és adequat, aquest valor sól ser petit.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'El nombre d\'escriptures fetes a la memòria intermitja d\'InnoDB.';
$strShowStatusInnodb_data_fsyncsDescr = 'El nombre d\'operacions fsync() aproximades.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'El nombre actual d\'operacions fsync() pendents.';
$strShowStatusInnodb_data_pending_readsDescr = 'El nombre actual de lectures pendents.';
$strShowStatusInnodb_data_pending_writesDescr = 'El nombre actual d\'escritures pendents.';
$strShowStatusInnodb_data_readDescr = 'La quantitat aproximada de dades llegides, en bytes.';
$strShowStatusInnodb_data_readsDescr = 'El nombre total de dades llegides.';
$strShowStatusInnodb_data_writesDescr = 'El nombre total de dades escrites.';
$strShowStatusInnodb_data_writtenDescr = 'La quantitat aproximada de dades escrites, en bytes.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'El nombre de dobles escriptures realitzades i el nombre de planes escrites per a aquest propòsit.';
$strShowStatusInnodb_dblwr_writesDescr = 'El nombre de dobles escriptures realitzades i el nombre de planes escrites per a aquest propòsit.';
$strShowStatusInnodb_log_waitsDescr = 'El nombre d\'esperes fetes degut al petit tamany de la memòria intermèdia del registre i a esperar a que s\'actualitzés abans de continuar.';
$strShowStatusInnodb_log_write_requestsDescr = 'El nombre de peticions d\'escriptura al registre.';
$strShowStatusInnodb_log_writesDescr = 'El nombre d\'escriptures físiques a l\'arxiu de registre.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'El nombre d\'escriptures fsync fetes a l\'arxiu de registre.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'El nombre d\'operacions fsync pendents a l\'arxiu de registre.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Escriptures pendents a l\'arxiu de registre.';
$strShowStatusInnodb_os_log_writtenDescr = 'El nombre de bytes escrits a l\'arxiu de registre.';
$strShowStatusInnodb_pages_createdDescr = 'El nombre de planes creades.';
$strShowStatusInnodb_page_sizeDescr = 'El tamany de plana d\'InnoDB compilat (per defecte 16KB). Bastants valors es comptabilitzen en planes; el tamany de plana permet convertir-lo fàcilment a bytes.';
$strShowStatusInnodb_pages_readDescr = 'El nombre de planes llegides.';
$strShowStatusInnodb_pages_writtenDescr = 'El nombre de planes escrites.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'El nombre de bloquejos de files actualment en espera.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'El temps promig en fer un bloqueig de fila, en milisegons.';
$strShowStatusInnodb_row_lock_timeDescr = 'El temps total emprat en fer bloquejos de files, en milisegons.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'El temps màxim en fer un bloqueig de fila, en milisegons.';
$strShowStatusInnodb_row_lock_waitsDescr = 'El nombre de vegades que un bloqueig de fila ha estat en espera.';
$strShowStatusInnodb_rows_deletedDescr = 'El nombre de files esborrades de taules InnoDB.';
$strShowStatusInnodb_rows_insertedDescr = 'El nombre de files afegides a taules InnoDB.';
$strShowStatusInnodb_rows_readDescr = 'El nombre de files llegides de taules InnoDB.';
$strShowStatusInnodb_rows_updatedDescr = 'El nombre de fles actualitzades en taules InnoDB.';
$strShowStatusKey_blocks_not_flushedDescr = 'El nombre de bloquejos de clau a la memòria cau de les claus que han canviat però que encara no han estat actualitzades a disc. Es coneix com a Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'El nombre de blocs no usats a la memòria cau de les claus. Aquest valor es pot fer servir per saber quànta memòria cau de les claus s\'utilitza.';
$strShowStatusKey_blocks_usedDescr = 'El nombre de blocs usats a la memòria cau de les claus. Aquest valor és la marca indicativa del màxim nombre de blocs usats mai a l\'hora.';
$strShowStatusKey_read_requestsDescr = 'El nombre de peticions de lectura d\'un bloc de clau de la memòria cau.';
$strShowStatusKey_readsDescr = 'El nombre de lectures físiques d\'un bloc de clau del disc. Si Key_reads és gran, llavors el valor de key_buffer_size probablement és massa petit. El rati de la memòria cau es pot calcular com Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'El nombre de peticions d\'escriptura d\'un bloc de clau a la memòria cau.';
$strShowStatusKey_writesDescr = 'El nombre d\'escriptures físiques d\'un bloc de clau a disc.';
$strShowStatusLast_query_costDescr = 'El cost total de la darrera consulta compilada tal com el valora l\'optimitzador de consultes. És útil per comparar el cost de diferents plans de consulta per a la mateixa consulta. El valor 0 vol dr que encara no s\'ha compilat cap consulta.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'El nombre de files esperant a ser escrites en cues INSERT DELAY.';
$strShowStatusOpened_tablesDescr = 'El nombre de taules que han estat obertes. Si el nombre de taules obertes és gran, probablement el valor de memòria cau de taula és massa petit.';
$strShowStatusOpen_filesDescr = 'El nombre d\'arxius que estàn oberts.';
$strShowStatusOpen_streamsDescr = 'El nombre de fluxes que estàn oberts (usats principalment per a registre).';
$strShowStatusOpen_tablesDescr = 'El nombre de taules que estàn obertes.';
$strShowStatusQcache_free_blocksDescr = 'El nombre de blocs de memòria lliures a la memòria cau de consultes.';
$strShowStatusQcache_free_memoryDescr = 'La quantitat de memòria liure per a memòria cau de consultes.';
$strShowStatusQcache_hitsDescr = 'El nombre d\'encerts a memòria cau.';
$strShowStatusQcache_insertsDescr = 'El nombre de consultes afegides a la memòria cau.';
$strShowStatusQcache_lowmem_prunesDescr = 'El nombre de consultes tretes de la memòria cau per alliberar memòria per deixar lloc a noves consultes. Aquesta informació pot ajudar a ajustar el tamany de la memòria cau de consultes. La memòria cau de consultes utilitza l\'estratègia menys recentment usada(least recently used - LRU) per decidir quines consultes treure de la memòria cau.';
$strShowStatusQcache_not_cachedDescr = 'El nombre de consultes no enviades a la memòria cau (no enviables, o no enviades degut al paràmetre query_cache_type).';
$strShowStatusQcache_queries_in_cacheDescr = 'El nombre de consultes registrades a la memòria cau.';
$strShowStatusQcache_total_blocksDescr = 'El nombre total de blocs a la memòria cau de consultes.';
$strShowStatusReset = 'Reiniciar';
$strShowStatusRpl_statusDescr = 'L\'estat de la replicació a prova d\'errades (no implementat encara).';
$strShowStatusSelect_full_joinDescr = 'El nombre de joins que no usen indexos. Si aquest valor no és 0, s\'haurien de comprovar acuradament els indexos de les taules.';
$strShowStatusSelect_full_range_joinDescr = 'El nombre de joins que han usat un rang de cerca en una taula de referència.';
$strShowStatusSelect_range_checkDescr = 'El nombre de joins sense claus que comproven per l\'ús de claus després de cada fila. (Si aquiest valor no és 0, s\'haurien de comprovar acuradament els indexos de les taules.)';
$strShowStatusSelect_rangeDescr = 'El nombre de joins que han usat rangs a la primera taula. (Normalment no és crític si el valor no és molt gran.)';
$strShowStatusSelect_scanDescr = 'El nombre de joins que han fet una cerca a la primera taula sencera.';
$strShowStatusSlave_open_temp_tablesDescr = 'El nombre de taules temporals obertes actualment pel fil esclau de SQL.';
$strShowStatusSlave_retried_transactionsDescr = 'Nombre total (des de l\'arrencada) de vegades que el fil esclau de replicació de SQL ha recuperat transaccions.';
$strShowStatusSlave_runningDescr = 'Aixó és ACTIU (ON) si aquest servidor és un esclau que està connectat a un mestre.';
$strShowStatusSlow_launch_threadsDescr = 'El nombre de fils que han tardat més que slow_launch_time segons a crear.';
$strShowStatusSlow_queriesDescr = 'El nombre de consultes que han tardat més que long_query_time segons.';
$strShowStatusSort_merge_passesDescr = 'El nombre de passades d\'intercal.lació que l\'algorisme de classificació ha hagut de fer. Si aquest valor és gran, s\'hauria de considerar incrementar el valor de la variable de sistema sort_buffer_size.';
$strShowStatusSort_rangeDescr = 'El nombre de classificacions fetes amb rangs.';
$strShowStatusSort_rowsDescr = 'El nombre de files classificades.';
$strShowStatusSort_scanDescr = 'El nombre de classificacions fetes cercant la taula.';
$strShowStatusTable_locks_immediateDescr = 'El nombre de vegades que un bloqueig de taula s\'ha fet immediatament.';
$strShowStatusTable_locks_waitedDescr = 'El nombre de vegades que un bloqueig de taula no s\'ha pogut fer immediatament i s\'ha necessitat una espera. Si aixó és alt, i es detecten problemes de rendiment, s\'hauria de considerar l\'optimització de les consultes, o també dividir la taula o taules en vàries o bé utilitzar la replicació.';
$strShowStatusThreads_cachedDescr = ' El nombre de fils a la memòria cau de fil. L\'index de memòria cau es pot comptar com Threads_created/Connections. Si aquest valor és vermell s\'hauria d\'augmentar el valor de thread_cache_size.';
$strShowStatusThreads_connectedDescr = 'El nombre de connexions obertes simultàniament.';
$strShowStatusThreads_createdDescr = ' El nombre de fils creats per gestionar connexions. Si Threads_created és gran, pots voler augmentar el valor de thread_cache_size. (Normalment això no dóna una millora de rendiment notable si es té una bona aplicació de fil.)';
$strShowStatusThreads_runningDescr = 'El nombre de fils que no estàn dormint.';
$strShowTableDimension = 'Mostra dimensió de les taules';
$strShowTables = 'Mostra taules';
$strShowThisQuery = ' Mostra aquesta consulta de nou ';
$strSimplifiedChinese = 'Xinés Simplificat';
$strSingly = '(només)';
$strSize = 'Mida';
$strSkipQueries = 'Nombre de registres(consultes) a saltar des de l\'inici';
$strSlovak = 'Eslovac';
$strSlovenian = 'Eslové';
$strSocketProblem = '(o el sòcol del servidor local MySQL no està configurat correctament)';
$strSortByKey = 'Classifica per la clau';
$strSort = 'Classificació';
$strSorting = 'Classificant';
$strSpaceUsage = 'Utilització d\'espai';
$strSpanish = 'Espanyol';
$strSplitWordsWithSpace = 'Paraules separades per un espai (" ").';
$strSQLExportCompatibility = 'Compatibilitat d\'exportació SQL';
$strSQLExportType = 'Tipus d\' Exportació';
$strSQLImportOptions = 'Opcions SQL';
$strSQLOptions = 'Opcions SQL';
$strSQLParserBugMessage = 'És possible que hagueu trobat un error a l\'intèrpret SQL. Si us plau, comproveu la sintaxi de la consulta i verifiqueu que les cometes estiguin al seu lloc i facin parelles. Un altra possible causa de l\'errada és que estigueu pujant un arxiu amb dades binàries per fora de l\'àrea de text delimitada. També podeu provar la consulta a la interfície de comandes de MySQL. La sortida següent generada pel servidor MySQL, si n\'hi ha, pot ajudar-vos a diagnosticar el problema. Si encara teniu problemes o si l\'intèrpret falla i l\'interfície de comandes funciona, reduïu la consulta a la part de l\'SQL que produeix l\'errada, i envieu un informe d\'error amb la cadena de dades de la secció de TALL indicada avall:';
$strSQLParserUserError = 'Sembla que hi ha un error a la consulta SQL. La sortida següent generada pel servidor MySQL, si n\'hi ha, pot ajudar-vos a diagnosticar el problema';
$strSQLQuery = 'crida SQL';
$strSQLResult = 'Resultat SQL';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Identificador Incorrecte';
$strSQPBugUnclosedQuote = 'Cometa no tancada';
$strSQPBugUnknownPunctuation = 'Signe de puntuació desconegut';
$strStatCheckTime = 'Darrera comprovació';
$strStatCreateTime = 'Creació';
$strStatement = 'Sentències';
$strStatisticsOverrun = 'En un servidor ocupat, els comptadors de bytes poden excedir el seu tamany, llavors les estadístiques donades pel servidor MySQL poden ser incorrectes.';
$strStatUpdateTime = 'Darrera actualització';
$strStatus = 'Estat';
$strStorageEngine = 'Motor d\'emmagatzematge';
$strStorageEngines = 'Motors d\'emmagatzematge';
$strStrucCSV = 'dades CSV ';
$strStrucData = 'Estructura i dades';
$strStrucDrop = 'Afegir DROP TABLE';
$strStrucExcelCSV = 'CSV per dades de MS Excel';
$strStrucNativeExcel = 'Dades Natives MS Excel';
$strStrucOnly = 'Només l\'estructura';
$strStructPropose = 'Proposa una estructura de taula';
$strStructure = 'Estructura';
$strSubmit = 'Enviar';
$strSuccess = 'La vostra comanda SQL ha estat executada amb èxit';
$strSum = 'Suma';
$strSwedish = 'Suec';
$strSwitchToDatabase = 'Canviar a la base de dades copiada';
$strSwitchToTable = 'Canvia a una taula copiada';

$strTableAlreadyExists = 'La taula %s ja existeix!';
$strTableComments = 'Comentaris de la taula';
$strTableEmpty = 'El nom de la taula és buit!';
$strTableHasBeenDropped = 'S\'ha esborrat la taula %s';
$strTableHasBeenEmptied = 'S\'ha buidat la taula %s';
$strTableHasBeenFlushed = 'S\'ha buidat la memòria cau de la taula %s';
$strTableMaintenance = 'Manteniment de la taula';
$strTableOfContents = 'Taula de continguts';
$strTableOptions = 'Opcions de Taula';
$strTables = '%s taula(es)';
$strTableStructure = 'Estructura de la taula';
$strTable = 'Taula';
$strTableType = 'Tipus de taula';
$strTakeIt = 'agafa';
$strTblPrivileges = 'Permissos especifics de taula';
$strTempData = 'Dades temporals';
$strTextAreaLength = ' A causa de la seva longitud,<br /> aquest camp pot no ser editable ';
$strThai = 'Tailandès';
$strThemeDefaultNotFound = 'Tema per defecte %s no trobat!';
$strThemeNoPreviewAvailable = 'No hi ha vista prèvia disponible.';
$strThemeNotFound = 'Tema %s no trobat!';
$strThemeNoValidImgPath = 'El camí de les imatges del tema %s és incorrecte!';
$strThemePathNotFound = 'No s\'ha trobat el camí de les imatges del tema %s!';
$strTheme = 'Tema / Estil';
$strThisHost = 'Aquest Host';
$strThisNotDirectory = 'Aixó no és un directori';
$strThreads = 'Fils';
$strThreadSuccessfullyKilled = 'Fil %s cancel.lat correctament.';
$strTimeoutInfo = 'La darrera importació ha esgotat el temps, després de reenviar continuarà des de la posició %d.';
$strTimeoutNothingParsed = 'Però a la darrera importació no s\'han processat dades, el que normalment indica que phpMyAdmin no ha pogut finalitzar aquesta importació a menys que incrementeu els límits de temps de php.';
$strTimeoutPassed = 'Temps exaurit de l\'arxiu d\'ordres, si voleu finalitzar l\'importació, torneu a enviar el mateix arxiu a importar i el procés continuarà.';
$strTime = 'Temps';
$strToggleScratchboard = 'Canvia l\' scratchboard';
$strTotal = 'total';
$strTotalUC = 'Total';
$strTraditionalChinese = 'Xinés Tradicional';
$strTraditionalSpanish = 'Espanyol Tradicional';
$strTraffic = 'Tràfic';
$strTransactionCoordinator = 'Coordinador de transaccions';
$strTransformation_application_octetstream__download = 'Mostra un enllaç per descarregar les dades binàries d\'un camp. La primera dada és el nom d\'arxiu binari. La segona dada és un possible nom de camp d\'una taula que contingui el nom d\'arxiu. Si es facilita la segona dada és necessari tenir la primera dada buida';
$strTransformation_application_octetstream__hex = 'Mostra la representació hexadecimal de les dades.';
$strTransformation_image_jpeg__inline = 'Mostra una miniatura am enllaç; opcions: ample,alt en pixels (respecta la proporció original)';
$strTransformation_image_jpeg__link = 'Es mostra com a enllaç a la imatge.';
$strTransformation_image_png__inline = 'Veure image/jpeg: en linia';
$strTransformation_text_plain__dateformat = 'Pren un camp TIME, TIMESTAMP o DATETIME i li dona format utilitzant el format d\'hora local. La primera opció es la diferència (en hores) que s\'ha d\'afegir a l\'hora (Per defecte: 0). La segona opció és un format de data diferent d\'acord als paràmetres disponibles per a la funció de PHP strftime().';
$strTransformation_text_plain__external = 'NOMÉS LINUX: Llença una aplicació externa i facilita el camp de dades via standard input. Retorna per standard output de l\'aplicacióo. El defecte és Tidy, per interpretar codi HTML. Per raons de seguretat, has d\' editar manualment el fitxer libraries/transformations/text_plain__external.inc.php i afegir les eines que vulguis fer servir. La primera opció és, llavors, el numero del programa que vols fer servir i la segona opció són els paràmetres per el programa. El tercer paràmetre, si es posa a 1, convertirà la sortida fent servir htmlspecialchars() (El defecte és 1). El quart paràmetre, si val 1, posarà un NOWRAP al contingut de les cel.les de forma que la sortida sencera es mostrarà sense reformatejar (Per defecte 1)';
$strTransformation_text_plain__formatted = 'Conserva el format original del camp. No es fa cap canvi.';
$strTransformation_text_plain__imagelink = 'Mostra una imatge i un enllaç, el camp conté el nom del fitxer; la primera opció és un prefixe com "http://domini.com/", la segona opció és l\'amplada en pixels, la tercera és l\'alçada.';
$strTransformation_text_plain__link = 'Mostra un enllaç, el camp conté el nom del fitxer; la primera opció és un prefixe com "http://domini.com/", la segona opció és el titol del enllaç.';
$strTransformation_text_plain__sql = 'Formateig del text com a consulta SQL amb resaltat de sintaxi.';
$strTransformation_text_plain__substr = 'Mostra una part d\'una cadena de text. La primera opció és el nombre de caracters a saltar des de l\'inici de la cadena (Per defecte 0). La segona opció és el nombre de caracters a retornar (Per defecte: fins al final de la cadena). La tercera opció és la cadena a afegir a l\'inici o al final quan hi ha truncament (Per defecte: "...").';
$strTruncateQueries = 'Talla les consultes mostrades';
$strTurkish = 'Turc';
$strType = 'Tipus';

$strUkrainian = 'Ucrainès ';
$strUncheckAll = 'Desmarcar tot';
$strUnicode = 'Unicode';
$strUnique = 'Única';
$strUnknown = 'Desconegut';
$strUnselectAll = 'Desmarca tot';
$strUnsupportedCompressionDetected = 'Intenteu carregar un arxiu amb una compresió no suportada (%s). O bé aquest suport no s\'ha implementat encara o bé el teniu desactivat a la configuració.';
$strUpdatePrivMessage = 'Heu actualitzat els permissos de %s.';
$strUpdateProfileMessage = 'S\'ha actualitzat el perfil.';
$strUpdateQuery = 'Actualitza consulta';
$strUpdComTab = 'Mira a la documentació com actualitzar la teva Taula de Comentaris de les Columnes';
$strUpgrade = 'Es necessari actualitzar a %s %s o posterior.';
$strUploadLimit = 'Probablement has triat d\'enviar un arxiu massa gran. Consulta la %sdocumentació%s per trobar formes de modificar aquest límit.';
$strUsage = 'Ús';
$strUseBackquotes = 'Usa &quot;backquotes&quot; amb taules i noms de camps';
$strUsedPhpExtensions = 'Extensions de PHP usades';
$strUseHostTable = 'Utilitza la Taula de Hosts';
$strUserAlreadyExists = 'L\'usuari %s ja existeix!';
$strUserEmpty = 'El nom d\'usuari és buit!';
$strUserName = 'Nom d\'usuari';
$strUserNotFound = 'No s\'ha trobat l\'usuari sel.leccionat a la taula de permissos.';
$strUserOverview = 'Informació general de l\'usuari';
$strUsersDeleted = 'S\'han esborrat correctament els usuaris sel.leccionats.';
$strUsersHavingAccessToDb = 'Usuaris amb accés a &quot;%s&quot;';
$strUser = 'Usuari';
$strUseTabKey = 'Usa la tecla TAB per moure\'t de valor en valor, o CTRL+fletxes per moure\'t on vulguis';
$strUseTables = 'Usa Taules';
$strUseTextField = 'Usa camp de texte';
$strUseThisValue = 'Fes servir aquest valor';

$strValidateSQL = 'Validar l\'SQL';
$strValidatorError = 'No s\'ha pogut iniciar el validador SQL. Si us plau, comproveu que teniu instal·lats els mòduls de PHP necessaris tal i com s\'indica a la %sdocumentació%s.';
$strValue = 'Valor';
$strVar = 'Variable';
$strVersionInformation = 'Informació de Versió';
$strViewDumpDatabases = 'Veure volcat (esquema) de les bases de dades';
$strViewDumpDB = 'Veure l\'esquema de la base de dades';
$strViewDump = 'Veure un esquema de la taula';
$strViewHasBeenDropped = 'Vista %s esborrada';
$strViewMaxExactCount = 'Aquesta vista té més de %d files. Consulteu a %sdocumentació%s.';
$strView = 'Vista';

$strWebServerUploadDirectory = 'Directori de pujada d\'arxius del servidor web';
$strWebServerUploadDirectoryError = 'No està disponible el directori indicat per pujar arxius';
$strWelcome = 'Benvingut a %s';
$strWestEuropean = 'Europa Occidental';
$strWildcard = 'comodins';
$strWindowNotFound = 'La finestra destí del navegador no s\'ha pogut actualitzar. Potser has tancat la finestra "pare" o bé el teu navegador bloqueja actualitzacions entre finestres per la teva configuració de seguretat';
$strWithChecked = 'Amb marca:';
$strWritingCommentNotPossible = 'No es pot gravar aquest comentari';
$strWritingRelationNotPossible = 'No es pot gravar aquesta relació';
$strWrongUser = 'Usuari i/o clau erronis. Accés denegat.';

$strXML = 'XML';

$strYes = 'Si';

$strZeroRemovesTheLimit = 'Nota: Establint aquestes opcions a 0 (zero) treu el limit.';
$strZip = '"comprimit amb zip"';

// To translate:

$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate

$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate

$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBPages = 'pages';  //to translate

$strReadRequests = 'Read requests';  //to translate

$strWriteRequests = 'Write requests';  //to translate

?>
